# MirrorLabs

This project aims to establish a generic bridge between a robotic system simulated/operated in ROS and Unity3D using ROS# (Using the 
unity asset [ROS#](https://assetstore.unity.com/packages/tools/physics/ros-107085) published by Siemens). This project is partially derived from the [Rviz2AR](https://github.com/Awesome-Technologies/Rviz2AR) repo published by 
[Awesome-Technologies](https://awesome-technologies.de/). Besides a generic Unity-Ros-Bridge it is planned to modify the [Rviz2AR](https://github.com/Awesome-Technologies/Rviz2AR) project for the recently available HoloLens 2.

The current state of the project includes the following content:

- MirrorLabs_Desktop directory, the complete unity project used directly for development of the generic UR5 ROS-Unity-Bridge. (Executable on Windows 10)
- MirrorLabs_HL2 directory, derivative of the desktop version for Augmented Reality using Microsoft Hololens (0.18362 or higher)
- MirrorLabs_Android directory, derivative of the desktop version for Augmented Reality using an Android Smartphone

Each of the Unity projects has a variety of sample scenes for Uninversal Robotic (UR3, UR5, UR10) and Doosan Robotic ( a0509, a0912, m0609, m0617, m1013, m1509). For each, only the IP address and the subscribed topic have to be adjusted!

## How to use 
### ROS
Set up ROS (melodic used for development, other may be compatible) environment,  
including the [rosbridge_suit](https://github.com/RobotWebTools/rosbridge_suite),
[ros-sharp ROS-components](https://github.com/siemens/ros-sharp/tree/master/ROS),
[Gazebo](http://gazebosim.org/), and download/install the latest ROS package for the robot in question, e.g. [UR ROS package](https://github.com/ros-industrial/universal_robot).

Once the all packages are installed, open the `launch` file and add the following lines to the launch procedure: 
```
<include file="$(find file_server)/launch/ros_sharp_communication.launch" > 
     <arg name="port" value="9090"/>
</include>>
 ```

Try out if the installation was succesful by activating the `.launch` file. E.g.:
```
$ roslaunch ur_gazebo ur5.launch
```

If everything works out, the gazebo GUI will open and the ROS-side of the setup is completed.


### Visual Studio 2019 
Instead of installing Unity first, the visual studio integration seemsto work better 
if Visual Studio is already present during Unity Installations. If Visual Studio 2019 is already installed, feel free to skip step 1,
only open the Visual Studio Installer. Next to the available installation of [Visual Studio 2019](https://visualstudio.microsoft.com/)
click on the `modify` button to enter the extension selection menu

1. Download [Visual Studio 2019](https://visualstudio.microsoft.com/) from [here](https://visualstudio.microsoft.com/downloads/), 
the version does not matter, Visual Studio 2019 Community is already sufficient and free of charge for non-commercial usage. 
(Note: This includes sufficient for HoloLens development!)
This will trigger the Visual Studio Installer to be downloaded, once the download is done, launch the Visual Studio Installer. 
Click through the Visual Studio Setup until it request a specification of extension to be installed.

2. Manage your [Visual Studio 2019](https://visualstudio.microsoft.com/) extension:
Once the overview of extensions is displayed, select the options for `Universal Windows Platform` [UWP, for HoloLens development]. (Make sure `C++ (v142) Universal Windows Platform tools`, 
`C++ (v141) Universal Windows Platform tools` as well as `Windows 10 SDK (10.0.17763.0)`(or later) are selected.)
![VS UWP Extension](RM_Graphics/VS_EXT_UWP.PNG)<br/>
![VS UWP Extension Specification](RM_Graphics/VS_EXT_UWP_Spec.PNG)<br/>
Futher, select `Game Development with Unity`, this will enable [Visual Studio 2019](https://visualstudio.microsoft.com/) to directly attach compiled code to [Unity3D](https://unity.com/).
If all extensions are selected hit the `install` (or `modify`, if it an installation was already available) button in the bottom right corner and wait until it is finished.<br/>
![VS Unity Extension](RM_Graphics/VS_EXT_Unity.PNG)<br/>


This concludes the [Visual Studio 2019](https://visualstudio.microsoft.com/) installation. Note: Earlier versions of Visual Studio are not supported for HoloLens developments anymore




### Unity 2019.4.18f1 (or later)


#### Installation
1. Install/Update [UnityHub](https://unity3d.com/get-unity/download), make sure to click on `download Unity Hub`. Once it is downloaded and installed,
click on the left hand side of the UnityHub GUI onto `Installs`. (After a fresh installation of Unity Hub this is empty.) 
Now we add a new installation by clicking on the `Add` button on the top right of the UnityHub GUI. On the appearing pop-up select `Unity 2019.4.18f1` (or later) and click on `Next`.

2. Configure the extensions to be installed alongside the general Unity Editor. Select `Microsoft Visual Studio Community 2019` in the `dev tools`-category, proceed by selecting `Android Build Support` and expanding the options for it. 
There enable `Android SDK & NDK Tools` and `Open JDK` to let Unity get a hold of the latest SDKs, it is possible to do this manually but it is unnecessary extra work. 
Further down make sure that `Universal Windows Platform Build Support` and  `Windows Build Support (IL2CPP)` are selected as well. 
(Within this project, iOS, Mac and Linux platform support is not considered but feel free to costumize your install further).<br\>
![Unity Modules to install](RM_Graphics/Unity_install_modules.PNG)

#### Project Integration

Clone this repo to your local storage (SSD storage highly recommended!), once everything appears in your file explorer, 
open `Unity Hub` and head to `Project` tab (left hand side of the GUI). Here all (to UnityHub) known local projects are displayed, to add the 
`MirrorLabs_XYZ` project, click on the `ADD` button, navigate to the just downloaded repo and select the `MirrorLabs_XYZ` directory.
Now the `Unity Hub` added the new project and by clicking on it, it will launch the Editor. (Note: This can take a moment.)

More information regarding how to set up Unity, VisualStudio, ROS and how to get started in AR/VR can be found on our project website [here](https://www.mirrorlabs.eu)

#### Unity Project Setup

Once the `Unity Editor` is launched, find/locate the `MirrorLabs` folder, open the `scenes` directory and double-click the `ML_UR5_Gazebo_Subscribed` scene. 
This will load the base scene for all UR5 developments, use-case specific scenes will be available within the scene-folder once they are finalized. 
All scenes in development are indicated with the preamble "Dev_", all finalized scenes with "ML_".


#### ML_ scene overview

All current ML_<manufacturer>_<robotType> scene conists of, for example, a [UR5](https://www.universal-robots.com/products/ur5-robot/)-object, the `RosConnector`-object, a `GUI`-object, a `Main Camera`-object, a `Directional Light` and an `EventSystem`.
The magic within this Unity project is done using the [ROS#](https://assetstore.unity.com/packages/tools/physics/ros-107085) Unity Asset published by Siemens.  Below follows a quick overview of the purpose of each beforehand mentioned object

1. `UR5 model`, imported using the URDF importer included in the [ROS#](https://assetstore.unity.com/packages/tools/physics/ros-107085) 
asset and modified to be used with the preselected `universal rendering pipeline` [URP]. It serves as direct visualization model of a physical robot.

2. `RosConnector`, contains the networking components which forward the messages, handles  publishing topics, subscribtions etc, between the remote system and the primary ROS environment. This can be configured relatively quickly depending on the purpose. 
Note: Please keep in mind to prevent a loop of messages. (e.g. do not listen to \joint_states while sending these at the same time.)

Note: Just press play and start exploring what all individual functions do. The input fields are self-explainatory!




#### Vision and Development

The following developments are currently in progress: 


* Streamlining the setup of new Unity scenes by extending the `MirrorLabs` configurator tab within the unity editor UI.
* Expansion of GUI development for HoloLens 2 (based on the [Rviz2AR](https://github.com/Awesome-Technologies/Rviz2AR) project by [Awesome-Technologies](https://awesome-technologies.de/) )
* Expansion of GUI development for VR (Oculus Quest).
* Seperate project for Oculus Quest development.
* Alternative Unity Project based on MQTT. 

#### Notes

First start your simulation within ROS and start the Unity side afterwards, in the `Console Box` of Unity (if still in the editor and not ported to another platform yet), a message regarding the connection state will appear shortly after launching the scene.
(This message will appear and warn of an unsucessful ROS-connection attempt, verify your IP and port parameters and try it again by hitting the `connect` button. Check the `Console Box`-message regarding the outcome.)


